@@ -1,29 +1,27 @@
 package Sort::Key::DateTime;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use strict;
 use warnings;
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(dtkeysort dtcmpstr);
+our @EXPORT_OK = qw(dtkeysort
+                    dtkeysort_inplace
+                    rdtkeysort
+                    rdtkeysort_inplac
+                    dtsort
+                    dtsort_inplace
+                    rdtsort
+                    rdtsort_inplace
+                    mkkey_datetime
+                    dtcmpstr);
 
 use Sort::Key qw(keysort_inplace);
 use DateTime;
 use Carp;
 
-sub dtkeysort (&@) {
-    my $k = shift;
-    keysort_inplace {
-	my $dt = &{$k};
-	my $key = eval { sprintf("%010d%06d%010d", $dt->utc_rd_values) };
-	$@ and croak "sorting key '$dt' generated for element '$_' is not a valid DateTime object ($@)";
-	$key;
-    } @_;
-    wantarray ? @_ : $_[0];
-}
-
 sub dtcmpstr ($) {
     my $dt=shift;
     my $key = eval { sprintf("%010d%06d%010d", $dt->utc_rd_values) };
@@ -31,6 +29,20 @@ sub dtcmpstr ($) {
     $key;
 }
 
+sub mkkey_datetime {
+    my $dt = @_ ? shift : $_;
+    sprintf("%010d%06d%010d", $dt->utc_rd_values);
+}
+
+use Sort::Key::Register dt => \&mkkey_datetime, 'string';
+use Sort::Key::Register datetime => \&mkkey_datetime, 'string';
+
+use Sort::Key::Maker dtkeysort => 'dt';
+use Sort::Key::Maker rdtkeysort => '-dt';
+use Sort::Key::Maker dtsort => \&mkkey_datetime, 'str';
+use Sort::Key::Maker rdtsort => \&mkkey_datetime, '-str';
+
+
 
 1;
 __END__
@@ -65,21 +77,41 @@ Inside C<{ CALC_DT_KEY }>, the object is available as C<$_>.
 NOTE: sorting order is undefined when floating and non floating
 DateTime keys are mixed.
 
-BTW, DateTime objects can be sorted as:
+=item rdtkeysort { CALC_DT_KEY } @array
 
-  my @sorted = dtkeysort { $_ } @unsorted;
+sorted C<@array> in descending order
+
+=item dtsort(@array)
+
+=item rdtsort(@array)
+
+sort an array of DateTime objects in ascending and descending order
+respectively.
+
+Example:
+
+  my @sorted = dtsort @unsorted;
 
 
-=item dtcmpstr($dt)
+=item dtkeysort_inplace { CALC_DT_KEY } @array
+
+=item rdtkeysort_inplace { CALC_DT_KEY } @array
+
+=item dtsort @array
+
+=item rdtsort @array
+
+sort C<@array> in place.
+
+=item mkkey_datetime($dt)
 
 generates string sorting keys for DateTime objects
 
 =back
 
-
 =head1 SEE ALSO
 
-L<Sort::Key>, perl L<sort> function docs.
+L<Sort::Key>, L<Sort::Key::Maker>, perl L<sort> function docs.
 
 L<DateTime> module documentation and FAQ available from the DateTime
 project web site at L<http://datetime.perl.org/>
@@ -90,7 +122,7 @@ Salvador FandiE<ntilde>o, E<lt>sfandino@yahoo.com<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005 by Salvador FandiE<ntilde>o
+Copyright (C) 2005, 2010 by Salvador FandiE<ntilde>o
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.4 or,
